@@ -28,10 +28,9 @@ class First(DataFrame):
     def __init__(self, digs, plot=True, save_plot=None, save_plot_kwargs=None):
         _check_digs_(digs)
         dig_name = f'First_{digs}_Dig'
-        Dig = arange(10 ** (digs - 1), 10 ** digs)
-        Exp = log10(1 + (1. / Dig))
-
-        DataFrame.__init__(self, {'Expected': Exp}, index=Dig)
+        exp_array, dig_array = _gen_first_digits_(digs)
+ 
+        DataFrame.__init__(self, {'Expected': exp_array}, index=dig_array)
         self.index.names = [dig_name]
 
         if plot:
@@ -57,13 +56,11 @@ class Second(DataFrame):
             figure file path/name.
     """
     def __init__(self, plot=True, save_plot=None, save_plot_kwargs=None):
-        a = arange(10, 100)
-        Expe = log10(1 + (1. / a))
-        Sec_Dig = array(list(range(10)) * 9)
 
-        df = DataFrame({'Expected': Expe, 'Sec_Dig': Sec_Dig})
+        exp, sec_digs = _gen_second_digits_()
 
-        DataFrame.__init__(self, df.groupby('Sec_Dig').sum())
+        DataFrame.__init__(self, {'Expected': exp, 'Sec_Dig': sec_digs})
+        self.set_index("Sec_Dig", inplace=True)
 
         if plot:
             plot_expected(self, 22, save_plot=save_plot,
@@ -88,16 +85,16 @@ class LastTwo(DataFrame):
             figure file path/name.
     """
     def __init__(self, num=False, plot=True, save_plot=None, save_plot_kwargs=None):
-        exp = array([1 / 99.] * 100)
+        exp, l2d = _gen_last_two_digits_(num=num)
         DataFrame.__init__(self, {'Expected': exp,
-                                  'Last_2_Dig': _lt_(num=num)})
+                                  'Last_2_Dig': l2d})
         self.set_index('Last_2_Dig', inplace=True)
         if plot:
             plot_expected(self, -2, save_plot=save_plot,
                           save_plot_kwargs=save_plot_kwargs)
 
 
-def _test_(digs):
+def _get_expected_digits_(digs):
     """Chooses the Exxpected class to be used in a test
 
     Args:
@@ -114,21 +111,55 @@ def _test_(digs):
         return LastTwo(num=True, plot=False)
 
 
-def _lt_(num=False):
-    """Creates an array with the possible last two digits
+def _gen_last_two_digits_(num=False):
+    """Creates two arrays, one with the possible last two digits and one with
+    thei respective probabilities
 
     Args:
         num: returns numeric (ints) values. Defaluts to False,
             which returns strings.
 
     Returns:
-        Array of ints or str, in any case representing all 100 possible
-            combinations of last two digits
+        exp (np.array): Array with the (constant) probabilities of occurrence of
+            each pair of last two digits 
+        l2d (np.array): Array of ints or str, in any case representing all 100
+            possible combinations of last two digits
     """
+    exp = array([1 / 99.] * 100)
+    l2d = arange(0, 100)
     if num:
-        n = arange(0, 100)
-    else:
-        n = arange(0, 100).astype(str)
-        n[:10] = array(['00', '01', '02', '03', '04', '05',
-                        '06', '07', '08', '09'])
-    return n
+        return exp, l2d
+    l2d = l2d.astype(str)
+    l2d[:10] = array(['00', '01', '02', '03', '04', '05',
+                    '06', '07', '08', '09'])
+    return exp, l2d
+
+def _gen_first_digits_(digs):
+    """Creates two arrays, one with the possible digits combinations and the
+    other with their respective expected probabilities according to Benford
+
+    Args:
+        digs (int): 1, 2 or 3, for generation of the first, first two, or first
+            three digits
+
+    Returns:
+        (tuple of arrays): the expected probabilities array and the digits
+            combination array. 
+    """
+    dig_array = arange(10 ** (digs - 1), 10 ** digs)
+    exp_prob = log10(1 + (1. / dig_array))
+    return exp_prob, dig_array
+
+def _gen_second_digits_():
+    """Creates two arrays, one with he possible second digits combinations and
+    the other with their respective expected probabilities according to Benford
+
+    Returns:
+        (tuple of arrays): the expected probabilities array and the second
+        digits array.
+    """
+    exp_f2d, _ = _gen_first_digits_(2)
+    sec_digs = range(10)
+    sec_digs_in_f2d = array(list(range(10)) * 9)
+    exp = array([exp_f2d[sec_digs_in_f2d == i].sum() for i in sec_digs])
+    return exp, array(sec_digs)
\ No newline at end of file
