@@ -1,7 +1,7 @@
 from pandas import Series, DataFrame
 from numpy import array, arange, log10, ndarray
-from .expected import _test_
-from .constants import digs_dict, rev_digs
+from .expected import _get_expected_digits_
+from .constants import DIGS, REV_DIGS
 from .stats import Z_score
 from .checks import _check_num_array_, _check_sign_, _check_decimals_
 
@@ -81,12 +81,12 @@ def get_times_10_power(data, decimals=2):
 
     ab = data.seq.abs()
 
-    if data.seq.dtypes == 'int64':
+    if data.seq.dtype == 'int':
         data['ZN'] = ab
     else:
         if decimals == 'infer':
             data['ZN'] = ab.astype(str).str\
-                .replace('.', '')\
+                .replace('.', '', regex=False)\
                 .str.lstrip('0')\
                 .str[:5].astype(int)
         else:
@@ -105,9 +105,9 @@ def get_digs(data, decimals=2, sign="all"):
 
     # First digits
     for col in ['F1D', 'F2D', 'F3D']:
-        temp = df.ZN.loc[df.ZN >= 10 ** (rev_digs[col] - 1)]
+        temp = df.ZN.loc[df.ZN >= 10 ** (REV_DIGS[col] - 1)]
         df[col] = (temp // 10 ** ((log10(temp).astype(int)) -
-                                  (rev_digs[col] - 1)))
+                                  (REV_DIGS[col] - 1)))
         # fill NANs with -1, which is a non-usable value for digits,
         # to be discarded later.
         df[col] = df[col].fillna(-1).astype(int)
@@ -123,7 +123,7 @@ def get_digs(data, decimals=2, sign="all"):
     return df
 
 
-def get_proportions(data):
+def get_found_proportions(data):
     """
     """
     counts = data.value_counts()
@@ -136,7 +136,7 @@ def get_proportions(data):
 def join_expect_found_diff(data, digs):
     """
     """
-    dd = _test_(digs).join(data).fillna(0)
+    dd =_get_expected_digits_(digs).join(data).fillna(0)
     # create column with absolute differences
     dd['Dif'] = dd.Found - dd.Expected
     dd['AbsDif'] = dd.Dif.abs()
@@ -148,7 +148,7 @@ def prepare(data, digs, limit_N=None, simple=False):
     by the ocurrences of the chosen digits, creating other computed
     columns
     """
-    df = get_proportions(data)
+    df = get_found_proportions(data)
     dd = join_expect_found_diff(df, digs)
     if simple:
         del dd['Dif']
@@ -173,7 +173,7 @@ def prep_to_roll(start, test):
     respective expected proportions for later application to the Series subset
     """
     if test in [1, 2, 3]:
-        start[digs_dict[test]] = start.ZN // 10 ** ((
+        start[DIGS[test]] = start.ZN // 10 ** ((
             log10(start.ZN).astype(int)) - (test - 1))
         start = start.loc[start.ZN >= 10 ** (test - 1)]
 
@@ -181,7 +181,7 @@ def prep_to_roll(start, test):
         Exp = log10(1 + (1. / ind))
 
     elif test == 22:
-        start[digs_dict[test]] = (start.ZN // 10 ** ((
+        start[DIGS[test]] = (start.ZN // 10 ** ((
             log10(start.ZN)).astype(int) - 1)) % 10
         start = start.loc[start.ZN >= 10]
 
@@ -192,7 +192,7 @@ def prep_to_roll(start, test):
         ind = arange(0, 10)
 
     else:
-        start[digs_dict[test]] = start.ZN % 100
+        start[DIGS[test]] = start.ZN % 100
         start = start.loc[start.ZN >= 1000]
 
         ind = arange(0, 100)
